@@ -68,7 +68,10 @@ def remove_svg_namespace(tree):
     """
     prefix = "{http://www.w3.org/2000/svg}"
     prefix_len = len(prefix)
-    for element in tree.iter():
+    iterator = (
+        tree.iter() if hasattr(tree, 'iter')
+        else tree.getiterator())
+    for element in iterator:
         tag = element.tag
         if hasattr(tag, "startswith") and tag.startswith(prefix):
             element.tag = tag[prefix_len:]
@@ -86,7 +89,6 @@ class Node(dict):
         self.text = node.text
 
         # Inherits from parent properties
-        # TODO: drop other attributes that should not be inherited
         if parent is not None:
             items = parent.copy()
             not_inherited = (
