@@ -20,7 +20,9 @@ SVG tags functions.
 
 """
 
-from .defs import linear_gradient, marker, pattern, radial_gradient, use
+from .defs import (
+    clip_path, linear_gradient, marker, mask, pattern, radial_gradient, use)
+from .image import image
 from .path import path
 from .shapes import circle, ellipse, line, polygon, polyline, rect
 from .svg import svg
@@ -29,10 +31,13 @@ from .text import text, text_path, tspan
 TAGS = {
     "a": tspan,
     "circle": circle,
+    "clipPath": clip_path,
     "ellipse": ellipse,
+    "image": image,
     "line": line,
     "linearGradient": linear_gradient,
     "marker": marker,
+    "mask": mask,
     "path": path,
     "pattern": pattern,
     "polyline": polyline,
